# I. INTRODUCTION
`pydata_master` is an all-in-one package for daily data operation that contains the most frequently used functions I need.

<div id="badges" align="center">
<img src="https://img.shields.io/pypi/pyversions/pydata_master?logoColor=brown&style=plastic" alt= "Version"/>
<img src="https://img.shields.io/pypi/dm/pydata_master" alt="Download Badge"/>
<img src="https://img.shields.io/github/last-commit/thinh-vu/pydata_master" alt="Commit Badge"/>
<img src="https://img.shields.io/github/license/thinh-vu/pydata_master?color=red" alt="License Badge"/>
</div>

# II. REFERENCES
## 2.1. How to use this package?
- Using pip to install the pre-built package on Pypip `pip install pydata_master`
- If you want to use the latest pydata_master version instead of the stable one, you can install it from the source with the following command:
`pip install git+https://github.com/thinh-vu/pydata_master.git@main`
- Import the whole package to your project: `from pydata_master import *`
- Import a specific part of the package: `from pydata_master.util import *`

## 2.2. Install dependencies
If you install the package from the Github source, you must install dependencies separately. You can run this command to install all of them at once.

```
!pip install trafilatura
!pip install df2gspread
!pip install pytube
!pip install nltk
!pip install trafilatura
!pip install google-auth-httplib2
```

## Google services
creds, gc = google_auth('YOUR_PATH_TO_JSON')

# III. APENDICES

![Datetime Frequencies](../main/src/pandas_daterange_freq_list.png)

# IV. 🙋‍♂️ CONTACT INFORMATION

<div id="badges" align="center">
  <a href="https://www.linkedin.com/in/thinh-vu">
    <img src="https://img.shields.io/badge/LinkedIn-blue?style=for-the-badge&logo=linkedin&logoColor=white" alt="LinkedIn Badge"/>
  </a>
  <a href="https://www.messenger.com/t/mr.thinh.ueh">
    <img src="https://img.shields.io/badge/Messenger-00B2FF?style=for-the-badge&logo=messenger&logoColor=white" alt="Messenger Badge"/>
  <a href="https://www.youtube.com/channel/UCYgG-bmk92OhYsP20TS0MbQ">
    <img src="https://img.shields.io/badge/YouTube-red?style=for-the-badge&logo=youtube&logoColor=white" alt="Youtube Badge"/>
  </a>
  </a>
    <a href="https://github.com/thinh-vu">
    <img src="https://img.shields.io/badge/GitHub-100000?style=for-the-badge&logo=github&logoColor=white" alt="Github Badge"/>
  </a>
</div>

---

If you want to support my open-source projects, you can "buy me a coffee" via [Patreon](https://patreon.com/thinhvu?utm_medium=clipboard_copy&utm_source=copyLink&utm_campaign=creatorshare_creator) or Momo e-wallet (VN). Your support will help to maintain my blog hosting fee & to develop high-quality content.

![momo-qr](https://github.com/thinh-vu/vnstock/blob/main/src/momo-qr-thinhvu.jpeg?raw=true)
